
class Calculator:

    @staticmethod
    def add(a, b):
        """
        Generate addition of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: sum of a and b
        """

        return a + b

    @staticmethod
    def sub(a, b):
        """
        Generate subtraction of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: subtract b from a
        """

        return a - b

    @staticmethod
    def mul(a, b):
        """
        Generate multiplication of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: multiplication of a and b
        """

        return a * b

    @staticmethod
    def div(a, b):
        """
        Generate division of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: Divide a by b
        """

        return a / b



import setuptools

with open("README.md", "r") as file:
    long_description=file.read()

setuptools.setup(
    name="python-project-vik",
    version="1.0.0",
    author="Vikram Shinde",
    author_email="vik.shinde@gmail.com",
    description="Python project for testing",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/vikramshinde12/python-project",
    packages=setuptools.find_packages(exclude=['tests*']),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=2.7',
    include_package_data=True,
    install_requires=[]
)